Crate reparo
reparo
0.1.0
All Items
Crate Items
Traits
Functions
Crate
reparo
Traits

Rewindable
any event that is to be rewinded should be rewindable
Functions

rewind_
broadcast
pass iterator of the rewindable, and send to kanal::channel
wait_
until_
timestamp